# -*- coding: utf-8 -*-
#!/usr/bin/python

# 必要なライブラリのインポート
import pygame, sys
from pygame.locals import *
import smbus
import math
import time

# センサーアドレス
DEV_ADDR = 0x68

# レジスターアドレス
ACCEL_XOUT = 0x3b
ACCEL_YOUT = 0x3d
ACCEL_ZOUT = 0x3f
TEMP_OUT = 0x41
GYRO_XOUT = 0x43
GYRO_YOUT = 0x45
GYRO_ZOUT = 0x47
PWR_MGMT_1 = 0x6b
PWR_MGMT_2 = 0x6c

bus = smbus.SMBus(1)

# Sleep解除.
bus.write_byte_data(DEV_ADDR, PWR_MGMT_1, 0)
speed=5

# 1バイトデータ読込
def read_byte(adr):
    return bus.read_byte_data(DEV_ADDR, adr)
    
# 2バイトデータ読込
def read_word(adr):
    high = bus.read_byte_data(DEV_ADDR, adr)
    low = bus.read_byte_data(DEV_ADDR, adr+1)
    val = (high << 8) + low
    return val

# センサーのデータ取得
def read_word_sensor(adr):
    val = read_word(adr)
    if (val >= 0x8000):         # 負の数
        return -((65535 - val) + 1)
    else:                       # 正の数
        return val 

# 加速度データの取得
def get_accel_data_lsb():
    x = read_word_sensor(ACCEL_XOUT)
    y = read_word_sensor(ACCEL_YOUT)
    z = read_word_sensor(ACCEL_ZOUT)
    return [x, y, z]

def get_accel_data_g():
    x,y,z = get_accel_data_lsb()
    x = int(speed*x / 16384.0)
    y = -int(speed*y / 16384.0)
    z = int(speed*z / 16384.0)
    return [x, y, z]

# 距離関数の定義
def get_dist(x1,y1,x2,y2):
    d=math.sqrt((x2-x1)**2+(y2-y1)**2)
    return d

# 画面の初期化
pygame.init()
f=10 # width of frame
r=10 # radius of circle

# 色の定義
BLACK = (  0,   0,   0)
WHITE = (255, 255, 255)
RED   = (255,   0,   0)
GREEN = (  0, 255,   0)
YELLOW = (255, 255,   0)
BLUE  = (  0,  0, 255)

# フォントの作成
sysfont = pygame.font.SysFont(None,40)

# テキストを描画したSurfaceを作成
team1 = sysfont.render("Team A", False ,GREEN)
team2 = sysfont.render("Team B", False, RED)

#ゴールの位置
goal1_x=200
goal1_y=80
goal2_x=200
goal2_y=320

# 画面サイズ
(w,h)=(w,h) = (400,400)   
(x,y) = (w/2, h/2)
WINDOW = pygame.display.set_mode((w, h), 0, 32)
screen = pygame.display.get_surface()
pygame.display.set_caption('Accel_game')

# ボール初期位置
x0=50
y0=200
x=x0
y=y0

# 得点初期値
score1=0
score2=0
check=0
speed=5

# 無限ループ
while True:
    # 画面更新
    pygame.display.update()
    
    # 更新時間間隔
    
    pygame.time.wait(30)
    # 画面の背景
    screen.fill((0, 20, 0, 0)) 
    
    # ゲーム枠の描画
    pygame.draw.rect(screen, YELLOW, Rect(0,0,w,f))
    pygame.draw.rect(screen, YELLOW, Rect(0,0,f,h))
    pygame.draw.rect(screen, YELLOW, Rect(w-f,0,f,h))
    pygame.draw.rect(screen, YELLOW, Rect(0,h-f,w,f))
    
    # ゴールの描画
    pygame.draw.rect(screen, GREEN, Rect(goal1_x-2*r,goal1_y-2*r,4*r,4*r))
    pygame.draw.rect(screen, RED, Rect(goal2_x-2*r,goal2_y-2*r,4*r,4*r))

    # チーム名の描画
    screen.blit(team1,(50, goal1_y-2*r))
    screen.blit(team2,(50, goal2_y-2*r))
    
    # 枠の端処理
    if x < f+r:
        x = f+r
    if x > w-f-r:
        x = w-r-f
    if y < f+r:
        y = f+r
    if y > h-f-r:
        y = h-f-r
    
    # ベント処理
    for event in pygame.event.get():
        # 画面の閉じるボタンを押したとき終了する
        if event.type == QUIT:
            pygame.quit()
            sys.exit()
    accel_x,accel_y,accel_z = get_accel_data_g()
    x+=accel_x
    y+=accel_y
    
    # チームAのゴール判定
    d=get_dist(x,y,goal1_x,goal1_y)
    if d<10:   
        score1+=1
        x=x0
        y=y0
        check=1   
    
    # チームBのゴール判定
    d=get_dist(x,y,goal2_x,goal2_y)
    if d<10:    
        score2+=1
        x=x0
        y=y0
        check=1
        
    # 得点表示  
    num1 = sysfont.render(str(score1), False, GREEN)
    num2 = sysfont.render(str(score2), False, RED)
    screen.blit(num2,(250, goal2_y-2*r))
    screen.blit(num1,(250, goal1_y-2*r))
    
    # ボールの描画
    pygame.draw.circle(screen,WHITE, (x, y), r)
    if check==1:
        # ゴールしたとき少し休む
        pygame.time.delay(1000)
        check=0
